<?php
/**
 * Projekt: WS-Reporter
 *          Aufruf der Benutzeranleitung
 *
 * Autor:    Wilfried Schollenberger
 *           WS Unternehmensberatung und Controlling-Systeme GmbH
 * Kontakt:  wisch@ws-unternehmensberatung.de
 * Lizenz:   GPL 3.0
 *
 * Stand:    13.8.2021
 *
 */
$topic="Anleitung zum WS-Reporter";
/**
 * Das Verhalten der Anzeige wird über den Integer $level gesteuert.
 * 
 * Level 0 zeigt das gesamte Kapitel mit allen Unterkapiteln und einem vorangestellten Verzeichnis ohne Links.
 * 
 * Level 1 bis 9 zeigen nur den Text und ggf. Unterkapitel an:
 * 1: Das aktuelle Kapitel ohne Links
 * 2: Das aktuelle Kapitel mit Links zum übergeordneten Kapitel und zu den Unterkapiteln
 * 3: Das aktuelle Kapitel mit allen Unterkapiteln ohne Links
 * 4: Das aktuelle Kapitel mit allen Unterkapiteln und einem level-2-Link auf das übergeordnete Kapitel
 * 
 * Ab Level 10 wird zusätzlich eine Verzeichnis-Box angezeigt, über die der Inhalt der Anzeige gesteuert werden kann.
 * In jedem Fall wird in der Kapitelanzeige nur das aktuelle Kapitel ohne Links und Unterkapitel angezeigt. 
 * Das angezeigte Kapitel wird über das Verzeichnis ausgewählt.
 * 
 * 10: Es wird das gesamte Verzeichnis mit allen Unterkapiteln angezeigt.
 * 11: Es wird das Verzeichnis ab dem ausgewählten Kapitel mit allen Unterkapiteln  
 *     aber ohne Link auf das übergeordnete Verzeichnis angezeigt.
 * 12: Es wird das Verzeichnis ab dem ausgewählten Kapitel mit allen Unterkapiteln  
 *     und einem Verzeichnis-Link auf das übergeordnete Verzeichnis angezeigt.
 * 13: Es wird das Verzeichnis mit dem ausgewählten Kapitel, mit Anzeige-Links auf die direkten Unterkapitel  
 *     und einem Verzeichnis-Link auf das übergeordnete Verzeichnis angezeigt.
 * 14: Es wird das Verzeichnis ab dem ausgewählten Kapitel mit Verzeichnis-Links auf die direkten Unterkapitel  
 *     und einem Verzeichnis-Link auf das übergeordnete Verzeichnis angezeigt.
 *  
 * Verzeichnis-Links und Anzeige-Links:
 * Ein Verzeichnis-Link aktualisiert auch das Verzeichnis. Dabei wird immer der Typ 14 verwendet.
 * Bei einem Anzeige-Link wird nur die Anzeige verändert. Das Verzeichnis bleibt stehen.
 * Wenn das verlinkte Kapitel keine Unterkapitel hat, wird aus dem Verzeichnis-Link immer ein Anzeige-Link.  
 *  
 * Level 99 gibt nur den Inhalt des Kapitels ohne Überschrift für die Anzeige in Javascript zurück. 
 *  
 * @var integer $level
 */

if (session_status() == PHP_SESSION_NONE)  session_start();
require_once './includes/wsrTranslate.inc';

 session_abort();

$level = 0;
if (array_key_exists('level', $_REQUEST)) $level = $_REQUEST['level'];
$part = 'index';
if (array_key_exists('part', $_REQUEST)) $part = $_REQUEST['part'];

$verzeichnis = array();

class Kapitel{
    public $name = "Kapitel";
    public $stufe = 1;
    public $titel = "Anleitung";
    public $inhalt = "kapitel.inc";
    public $unterKapitel = array();
    public $gehoertZu = null;
    
    function __construct($name,$titel){
        global $verzeichnis;    
        if (array_key_exists($name, $verzeichnis)){
            throw new ErrorException("Das Kapitel $name gibt es schon.");
        }
        $verzeichnis[$name] = $this;
        $this->name = $name;
        $sprache = 'de';
        if (array_key_exists('Sprache', $_SESSION) && strlen($_SESSION['Sprache']) >= 2) $sprache = substr($_SESSION['Sprache'],0,2);
        if ($sprache != 'de' && file_exists('./anleitung/'.$name.'_'.$sprache.'.inc'))
            $this->inhalt = $name.'_'.$sprache.'.inc';
        else $this->inhalt = $name.'.inc';
        $this->titel = WSRTranslate::translate($titel);
    }
    function addUnterkapitel($name,$titel){
        $unterKapitel = new Kapitel($name,$titel);
        $this->unterKapitel[] = $unterKapitel;
        $unterKapitel->stufe = $this->stufe+1;
        $unterKapitel->gehoertZu = $this;
        return $unterKapitel;
    }

    function kapitelAnzeigen($mitLinks){
        if ($mitLinks && $this->gehoertZu != null){
            $n= $this->gehoertZu->name;
            $t= $this->gehoertZu->titel;
            $s=$this->gehoertZu->stufe;
            echo "<H{$this->stufe}>aus <a href=\"./anleitung.php?level=2&part={$n}\">{$t}</a></H{$s}>\n";
            
        }
        echo "<H{$this->stufe}>$this->titel</H{$this->stufe}>\n";
        include "./anleitung/".$this->inhalt;
        if ($mitLinks && count($this->unterKapitel) > 0){
            echo '<br>Unterkapitel:<ol>';
            foreach ($this->unterKapitel as $k){
                echo "\n<li> <a href=\"./anleitung.php?level=2&part={$k->name}\">";
                  echo $k->titel.'</a></li>';
            }
            echo "\n</ol>\n";
        }
    }
    function kapitelGanzAnzeigen($mitLinks){
        if ($mitLinks && $this->gehoertZu != null){
            echo "<H{$this->gehoertZu->stufe}>aus <a href=\"./anleitung.php?level=2&part={
                    $this->gehoertZu->name}\">{$this->gehoertZu->titel}</a></H{$this->gehoertZu->stufe}>\n";
                    
        }
        echo "<H{$this->stufe}>{$this->titel}</H{$this->stufe}>\n";
        include "./anleitung/".$this->inhalt;
        if (count($this->unterKapitel) > 0){
            foreach ($this->unterKapitel as $k){
                $k->kapitelGanzAnzeigen(false);
            }
        }
    }
    
    function titelAnzeigen() {
        echo "<H{$this->stufe}>{$this->titel}</H{$this->stufe}>\n";        
    }
    
    /*
     * Anzeige der Unterkapitel-Einträge zu einem Kapitel im Verzeichnis
     * Die Kapitel-Überschrift erfolgt separat im aufrufenden Programm. 
     * Auch die Umrahmung der <li>-Einträge mit <ol> oder <ul> erfolgt im aufrufenden Programm.
     * 
     * $_REQUEST['level'] (integer): Steuerung der erstellten Links: 
     *     10, 11, 12: Es werden alle Unterkapitel angezeigt, sonst nur die direkten
     *     14: es werden Verzeichnis-Links für die Unterkapitel mit weiteren Unterkapitel erstellt
     * 
     */
    function verzeichnisAnzeigen(){
        global $level;
        if ($level < 10) return;
        foreach ($this->unterKapitel as $k){
            if (count($k->unterKapitel) > 0 && $level >= 14) {
                echo "\n<li> <a href='./anleitung.php?level=14&part={$k->name}'>{$k->titel}</a>";
//                echo "\n<li> <a onclick=\"anzeige('{$k->name}');verzeichnis('{$k->name}');\">{$k->titel}</a></li>";
            }
            else{
                echo "\n<li> <a href='#Anzeige' onclick=\"anzeige('{$k->name}');\">{$k->titel}</a>";
            }
            if ($level < 13 && count($k->unterKapitel) > 0){
                echo "\n<ul>";
                $k->verzeichnisAnzeigen();
                echo "</ul>";
            }
            echo "</li>";
        }
    }
}


/**
 * Struktur der Anleitung aufbauen
 * @var Kapitel $anleitung: Wurzel der Anleitung
 */
$anleitung = new Kapitel("index", "Anleitung zum WS-Reporter");

$anlA = $anleitung->addUnterkapitel('start', 'Allgemeine Einführung');
$anlAH = $anlA->addUnterkapitel('startHinweise', 'Allgemeine Hinweise');
$anlA->addUnterkapitel('startFenster', 'Behandlung der Fenster bzw. Tabs');
$anlA->addUnterkapitel('startVerwaltung', 'Benutzer und Rollen');
$anlA->addUnterkapitel('startStatistik', 'Statistik und Freigaben');
$anlA->addUnterkapitel('startDragAndDrop', 'Drag and Drop');
$anlA->addUnterkapitel('startGetLinks', 'Statische Report-Aufrufe');
$anlA->addUnterkapitel('startSprachen', 'Sprachen');

$anlDQ = $anleitung->addUnterkapitel('datenquellen', 'Datenquellen');
$anlDG = $anlDQ->addUnterkapitel('dqGlobal', 'Globale Eigenschaften');
$anlDG->addUnterkapitel('dqMuster', 'Muster');
$anlDG->addUnterkapitel('dqWerteAuswahl', 'Werte-Auswahl');
$anlDQ->addUnterkapitel('dqMeta1', 'Metadaten-Editor');
$anlDQ->addUnterkapitel('dqZeilen', 'Zeilen');
$anlDQ->addUnterkapitel('dqWerte', 'Werte');
$anlDQF = $anlDQ->addUnterkapitel('dqFilter', 'Filter');
$anlDQF->addUnterkapitel('dqFilterListen', 'Filter-Listen');
$anlDQF->addUnterkapitel('dqDefaultFilter', 'Default-Filter');
$anlDQ->addUnterkapitel('dqListe', 'Auswahllisten');
$anlDQ->addUnterkapitel('dqDimensionen', 'Dimensionen');
$anlDQ->addUnterkapitel('dqHistorisierung', 'Historisierung');
$anlDQ->addUnterkapitel('dqJoins', 'Verknüpfte Datenquellen');
$anlDQ->addUnterkapitel('dqActions', 'Weitere Befehle');

$anlREP = $anleitung->addUnterkapitel('reports', 'Report-Definitionen');
$anlREPG = $anlREP->addUnterkapitel('rdTitle', 'Globale Eigenschaften');
$anlREPG->addUnterkapitel('rdWerteAuswahl', 'Werte-Auswahl');
$anlREP->addUnterkapitel('rdZeilen', 'Zeilen');
$anlREP->addUnterkapitel('rdWerte', 'Werte');
$anlREP->addUnterkapitel('rdSpalten', 'Spalten');
$anlREPF = $anlREP->addUnterkapitel('rdFilter', 'Filter');
$anlREPF->addUnterkapitel('rdWindowFilter', 'Anzeige-Filter');
$anlREP->addUnterkapitel('rdJoins', 'Verknüpfte Datenquellen');
$anlREP->addUnterkapitel('rdHistorisierung', 'Historisierung');
$anlREP->addUnterkapitel('rdQuellen', 'Quellenbeschreibung');
$anlREP->addUnterkapitel('rdRepLinks', 'Report-Links');
$anlREP->addUnterkapitel('rdReports', 'Report-Verwaltung');
$anlREP->addUnterkapitel('rdActions', 'Weitere Befehle');

$anlOutput = $anleitung->addUnterkapitel('outputReport', 'Report-Ausgabe');
$anlOutput->addUnterkapitel('outputWerteAuswahl', 'Werte-Auswahl');
$anlOutput->addUnterkapitel('outputReqFilter', 'Erforderliche Filter');

$anlDaten = $anleitung->addUnterkapitel('anlDaten', 'Zur Datenaufbereitung');
$anlDaten->addUnterkapitel('anlDatenDim', 'Dimensionen');
$anlDaten->addUnterkapitel('anlDatenHist', 'Historisierung');

$anlInstallation = $anleitung->addUnterkapitel('installation', 'Installation');
$anlInstallation->addUnterkapitel('instStart', 'Programme und Tabellen');
$anlInstallation->addUnterkapitel('instReportVrz', 'Reportverzeichnis anlegen');
$anlInstallation->addUnterkapitel('instIndexPHP', 'Anpassen der Anmeldeseite');
$anlInstallation->addUnterkapitel('benutzerVerwaltung', 'Benutzer-Verwaltung');
$anlInstallation->addUnterkapitel('rollenVerwaltung', 'Rollen-Verwaltung');
$anlInstallation->addUnterkapitel('instCSS-Anpassungen', 'CSS-Anpassungen');

$anlTips = $anleitung->addUnterkapitel('tipps', 'Hinweise und Probleme');
$anlTips->addUnterkapitel('tNamen', 'Namen bei Zeilen und Filter');
$anlTips->addUnterkapitel('tNulls', 'Probleme mit Blanks und Null-Werten');
$anlTips->addUnterkapitel('tCollations', 'Illegal mix of collations');
$anlTips->addUnterkapitel('tSpreadsheet', 'Ausgabe als Spreadsheet');
$anlTips->addUnterkapitel('tMysql', 'Problem bei MySql');
$anlTips->addUnterkapitel('tIndizes', 'Indizes und MariaDB');


if (array_key_exists($part, $verzeichnis)){
    $kapitel = $verzeichnis[$part];
    if (FALSE) $kapitel = new Kapitel('N', "T");
    if ($level == 11) $topic .= ': '.$kapitel->titel;
    elseif ($level < 10) $topic = $kapitel->titel;
}else{
    http_response_code(425);
    echo  'Inhalt für '.$part.' nicht gefunden.';
    die;
}

if ($level == 99){    
    if (file_exists('./anleitung/'.$part.'.inc')){
        $kapitel->titelAnzeigen();
        $sprache = 'de';
        if (array_key_exists('Sprache', $_SESSION) && strlen($_SESSION['Sprache']) >= 2) $sprache = substr($_SESSION['Sprache'],0,2);
        error_log ('Anleitung in '.$sprache.' - suche ./anleitung/'.$part.'_'.$sprache.'.inc');
        if ($sprache != 'de' && file_exists('./anleitung/'.$part.'_'.$sprache.'.inc'))
            include './anleitung/'.$part.'_'.$sprache.'.inc';
        else  include './anleitung/'.$part.'.inc';
        return;
    }
    http_response_code(425);
    echo  'Inhalt für '.$part.' nicht gefunden.';
    die;
}

if ($level == 98){
    // Fußzeile neu liefern
    $letztesKapitel = null;
    foreach ($verzeichnis as $vKapitel){
        if ($vKapitel == $kapitel){
            if ($letztesKapitel != null){
                $titel = WSRTranslate::translate($letztesKapitel->titel);
                echo "<a href='#Anzeige' class=\"Fleft\" onclick=\"anzeige('{$letztesKapitel->name}')\">{$titel}</a>";
            }
        }
        if ($letztesKapitel == $kapitel){
            if ($vKapitel != null){
                $titel = WSRTranslate::translate($vKapitel->titel);
                echo "<a href='#Anzeige' class=\"Fright\" onclick=\"anzeige('{$vKapitel->name}')\">{$titel}</a>";
            }
        }
        $letztesKapitel = $vKapitel;
    }
    return;
}

?>

<!DOCTYPE html>
<html>
<head>
<meta charset="UTF-8"><title><?=$topic ?></title>
<meta name="GENERATOR" content="WS-PHP: anleitung.php">
<link rel="stylesheet" href="./jscss/standard2.css">
<script type="text/javascript" src="./jscss/WSRAnleitung.js">
	</script>
</head>
<?php 
if ($level < 10){
    echo '<body class="simple">';
//    $kapitel->titelAnzeigen();
    switch ($level){
        case 0: 
        case 3: $kapitel->kapitelGanzAnzeigen(false);
        break;
        case 1: $kapitel->kapitelAnzeigen(false);
        break;
        case 2: $kapitel->kapitelAnzeigen(true);
        break;
        case 4: $kapitel->kapitelGanzAnzeigen(true);
        break;
    }
    echo '</body></html>';
    return;
}else{
if ($_SERVER["HTTP_HOST"] == "localhost:8898"){
    ?>
<body class = "entwicklung">	
<?php
} else echo '<body>';
?>

<h1><?=$topic ?></h1>
<div class="inlineBox anleitungBox">
<h2>Verzeichnis</h2>
<?php
if ($kapitel->gehoertZu != null)
echo "<a href='./anleitung.php?level=14&part={$kapitel->gehoertZu->name}'>{$kapitel->gehoertZu->titel}</a><br>";

echo "\n <a href='#Anzeige'  onclick=\"anzeige('{$kapitel->name}')\">{$kapitel->titel}</a>";

echo '<ol>'; $kapitel->verzeichnisAnzeigen(); echo '</ol>';
?>
</div>
<div class="inlineBox anleitungBox" id="Anzeige">
<?php 
// $kapitel->titelAnzeigen();
 $kapitel->kapitelAnzeigen(false);
?>  

</div>
<?php 
}
if ($level >= 10){
?>
<br>
<footer class="leiste" id='footer'>
<?php
    $letztesKapitel = null;
    foreach ($verzeichnis as $vKapitel){
        if ($vKapitel == $kapitel){
            if ($letztesKapitel != null){
                $titel = WSRTranslate::translate($letztesKapitel->titel);
                echo "<a class=\"Fleft\" href='#Anzeige'  onclick=\"anzeige('{$letztesKapitel->name}')\">{$titel}</a>";
            }
        }
        if ($letztesKapitel == $kapitel){
            if ($vKapitel != null){
                $titel = WSRTranslate::translate($vKapitel->titel);
                echo "<a class=\"Fright\" href='#Anzeige'  onclick=\"anzeige('{$vKapitel->name}')\">{$titel}</a>";
            }
        }
        $letztesKapitel = $vKapitel;
    }
?>
</footer>
<?php 
}
?>
</body>
</html>
