<?php
/**
 * Projekt: WS-Reporter
 *          Filter-Informationen für Benutzerverwaltung
 *
 * Autor:    Wilfried Schollenberger
 *           WS Unternehmensberatung und Controlling-Systeme GmbH
 * Kontakt:  wisch@ws-unternehmensberatung.de
 * Lizenz:   GPL 3.0
 *
 * Stand:    7.12.2021
 *
 * Parameter: user: der ausgewählte Benutzer
 *            table: Datenquelle oder '' wenn globaler Filter
 *            filter: eingegebener Filter-Name
 */
include 'includes/defender.inc';
require_once  'includes/classes.inc';
require_once 'includes/funktionen.inc';

adminRechteVerlangen();
$user = $_REQUEST['userName'];
$table = $_REQUEST['table'];
$filter = $_REQUEST['filter'];
?>
<!DOCTYPE html>
<html>
<head>
<meta charset="UTF-8"><title>Informationen zum Filter <?= $filter?></title>
<meta name="GENERATOR" content="WS-PHP: anleitung.php">
<link rel="stylesheet" href="./jscss/standard2.css">
<script type="text/javascript" src="./jscss/tableHeader.js">
	</script>
</head>
<body>
<h1>Informationen zum Filter <?= $filter?></h1>
<?php 
if (isValid($filter) && ! isValid($table)){
    $sql = new SqlAbfrage('WSR');
    $sql->sql = "select m.table_name, a1.attribute as label, m.column_name, m.qSelectVar, a4.attribute as phys_table from queryColumnMetadata m \n"
        ." left join queryAttribute a1 on a1.SatzTyp = 2 and a1.table_name = m.table_name \n"
        ." left join queryAttribute a4 on a4.SatzTyp = 4 and a4.table_name = m.table_name \n";
   
       $sql->addKlausel(' where m.table_name in (select r.table_name from wsrRechte r  where binary user = ', $user);       
       $sql->sql .= " )\n";
       $sql->sql .= " and m.qFilterTyp > 0";
    $sql->addKlausel(' and binary m.column_name =', trim($filter));
    
  
   $sql->sql .= ' order by m.table_name';
   $stmt = $sql->execute();
//   echo '<pre>'.$sql->sql;
//   echo '</pre>';
    ?>
<h2>Der Filter <?= $filter?> wird in folgenden Datenquellen verwendet.</h2>
<table id = "Tabelle1">
<thead>
<tr><th>Name</th><th>Label</th><th>Spalten-Name</th><th>Select-Ausdruck</th><th>phys. Tabelle</th></tr>
</thead>
<tbody>    
<?php 
while ($z = $stmt->fetchObject()){
?>
<tr><th class="left"><?= $z->table_name ?></th><td><?= $z->label ?><td><?= $z->column_name ?></td><td><?= $z->qSelectVar ?></td><td><?= $z->phys_table ?></td></tr>
<?php 
    }
}

if (!isValid($filter) &&  isValid($table)){
    $sql = new SqlAbfrage('WSR');
    $sql->sql = "select m.column_name as name, m.column_label as label, m.qSelectVar, a4.attribute as phys_table from queryColumnMetadata m \n"
//        ." left join queryAttribute a1 on a1.SatzTyp = 1 and a1.table_name = m.table_name \n"
        ." left join queryAttribute a4 on a4.SatzTyp = 4 and a4.table_name = m.table_name \n";
   
       $sql->addSel('m.table_name = ', $table);       
       $sql->sql .= " and m.qFilterTyp > 0";
//    $sql->addKlausel(' and m.column_name =', $filter);
   $sql->sql .= ' order by m.column_name';
   $stmt = $sql->execute();
//   echo '<pre>'.$sql->sql;
//   echo '</pre>';
    ?>
<h2>Die Tabelle <?= $table?> hat folgende Filter.</h2>
<table id = "Tabelle1">
<thead>
<tr><th>Name</th><th>Label</th><th>Select-Ausdruck</th><th>phys. Tabelle</th></tr>
</thead>
<tbody>    
<?php 
while ($z = $stmt->fetchObject()){
?>
<tr><th class="left"><?= $z->name ?></th><td><?= $z->label ?></td><td><?= $z->qSelectVar ?></td><td><?= $z->phys_table ?></td></tr>
<?php 
    }
?>
</tbody></table>
<?php 
}

if (isValid($filter) &&  isValid($table)){
    $sql = new SqlAbfrage('WSR');
    $sql->sql = "SELECT q1.table_name, q1.SatzTyp, q1.attribute as label, m.qSelectVar FROM `queryAttribute` q1 \n"
        ." left join queryColumnMetadata m on q1.table_name = m.table_name and m.qFilterTyp > 0 \n";
    $sql->firstWhere = false;
    $sql->addSel('binary m.column_name = ', trim($filter));
    $sql->firstWhere = true;
    $sql->addSel('q1.table_name = ', $table);
    $sql->sql .= " and q1.SatzTyp = 2 \n";
    $sql->sql .= "UNION SELECT q1.attribute as table_name, q1.SatzTyp, q2.attribute as label, m.qSelectVar FROM `queryAttribute` q1 \n"
        ." left join `queryAttribute` q2 on q2.table_name = q1.attribute and q2.satzTyp = 2 \n"
        ." left join queryColumnMetadata m on q1.attribute = m.table_name";
    $sql->addSel('binary m.column_name = ', trim($filter));    
    $sql->sql .= " and m.qFilterTyp > 0 \n";
    $sql->sql .= "where q1.SatzTyp >= 100 and q1.table_name != q2.table_name\n";
    $sql->addSel('q1.table_name = ', $table);
    
     $sql->sql .= ' order by SatzTyp';
     $stmt = $sql->execute();
     //   echo '<pre>'.$sql->sql;
     //   echo '</pre>';
     ?>
<h2>Der Filter <?= $filter?> in Tabelle <?= $table?> wirkt in folgenden Datenquellen:</h2>
<table id = "Tabelle1">
<thead>
<tr><th>Name</th><th>Label</th><th>Select-Ausdruck</th></tr>
</thead>
<tbody>    
<?php 
while ($z = $stmt->fetchObject()){
?>
<tr><th class="left"><?= $z->table_name ?></th><td><?= $z->label ?></td><td><?= $z->qSelectVar ?></td></tr>
<?php 
    }
?>
</tbody></table>
<?php 
}



?>

</body>
</html>

