<?php
/**
 * Projekt: WS-Reporter
 *          Spezifikation einer Datenquelle einlesen
 *
 * Autor:    Wilfried Schollenberger
 *           WS Unternehmensberatung und Controlling-Systeme GmbH
 * Kontakt:  wisch@ws-unternehmensberatung.de
 * Lizenz:   GPL 3.0
 *
 * Stand:    13.8.2022 ms
 *
 */
require_once './phpsec/createDBH.inc';
require_once './includes/classes.inc';
require_once './includes/qTranslate.inc';


function loadSimpleClassDef($query){
    loadClassDef0($query, false);
//    error_log('Simple Class Def.'.print_r($query,true));
}

/**
 * 
 * @param Query $query
 */
function loadClassDef($query){
    loadClassDef0($query, true);
    setdbDWH($query->dwh);
}

/**
 * 
 * @param Query $query
 * @param bool $mitJoins
 */
function loadClassDef0($query, $mitJoins){
//  if (false) $query = new Query;
    global $sourceSQL, $queryVersion, $dwhListe;
    $sourceSQLSave = $sourceSQL;
    $sourceSQL = false;
    $queryVersion = "0.1";
    $query->rowVars = array();
    $query->valueVars = array();
    $query->filterVars = array();
    $query->dimensions = array();
    $query->defaultFilter = array();
    $query->metaData = array();
    $query->addQueries = new Vector();
    $query->repRows = new Vector();
    $query->repValues = new Vector();
    $query->repColumns = new Vector();
    $query->repFilter = new Vector();
    $query->repTables = new Vector();
    
    if ($query->class_table == null) {
        echo '$query->class_table == null';
        return;
    }
    error_log('Load Class-Def '.$query->class_table);
    
    // Verwendung zählen
        $logSql = new SqlAbfrage('WSR');
        $logSql->sql = 'update wsrAdminQuery set lastUse=current_date(), useCounter = useCounter+1';
        $logSql->addSel('table_name = ', $query->class_table);
        $erg = $logSql->executeE(false);
        if ($erg === false || $erg->rowCount() < 1 ){
            error_log('Fehler beim Update wsrAdminQuery: '. $logSql->errorInfo()[2]);
        }
    
    

    $sql = new SqlAbfrage('WSR');
    $sql->sql = "select * from queryAttribute";
    $sql->addSel('table_name = ', $query->class_table);
    $sql->sql .= " order by SatzTyp";
    
    $stmt = $sql->execute();
    if ($stmt === false){
        echo '<pre> '.$query->class_table.":\n"; var_dump($sql->errorInfo()); var_dump($sql); echo '</pre>';
    }else{        
    while($z = $stmt->fetchObject()){
        switch ($z->SatzTyp){
            case 1: $query->defaultTitle  = $z->attribute;
                    break;
            case 2: $query->outputTitlePrefix = $z->attribute;
                    break;            
            case 3: $query->reportCSS = $z->attribute;
            break;
            case 4: $query->phys_table = $z->attribute;
            break;
            case 10: $query->queryType = 1*$z->attribute;
            break;
            case 11: $query->histType = 1*$z->attribute;
            break;
            case 12: 
                // ?? unklar warum if ($mitJoins) 
                $query->historyOption = 1*$z->attribute;
            break;
            case 13: $query->histAb = $z->attribute;
            break;
            case 14: $query->histBis = $z->attribute;
            break;
            case 15: $query->histStichtag = $z->attribute;
            break;
            case 16: $query->reportHoverMode = 1* $z->attribute;
            break;
            case 17: if ($query->historyOption == HistoryOptions::HSDATUM)
                    $query->historyDate = $z->attribute;
            break;
            case 19: $sprachen = $z->attribute;
                if (isValid($sprachen)){
                    $aSprachen = explode(' ', $sprachen);
                    $query->qLanguage = $aSprachen[0];
                    $query->qTranslations = array();
                    for ($i = 1; $i < count($aSprachen); $i++)
                        if ($aSprachen[$i] != $aSprachen[0])
                            $query->qTranslations[] = $aSprachen[$i];
                }
                $userLanguage = substr($_SESSION['Sprache'],0,2);
                if (array_search($userLanguage, $aSprachen)){
                    $query->currentLanguage = $userLanguage;
                }else{
                    $query->currentLanguage = $aSprachen[0];
                }
                error_log('aktive Sprache der Datenquelle: '.$query->class_table.': '.$query->currentLanguage);
                error_log('User:'.$userLanguage);
            break;
            case 18: $query->hatWerteAuswahl = true;
            break;
            case 50: 
            case 5: $query->table_description = $z->attribute;
            break;
            case 6: $queryVersion = $z->attribute;
            break;
            case 7: if (in_array($z->attribute, $dwhListe)) $query->dwh = $z->attribute;
                else {
                    error_log('Datenbank '.$z->attribute.' ist nicht bekannt.');
                    echo WSRTranslate::translate('FEHLER: Datenbank').' '.$z->attribute.' '.WSRTranslate::translate('ist nicht bekannt.');
                }
            break;
            case 8: $query->dimKey = $z->attribute;
            break;
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
                $query->table_description .= $z->attribute;
                break;
        }
        if ($z->SatzTyp >= 100
            && $z->SatzTyp < 150
            && $mitJoins){
            $aq = new AddedQuery($z->attribute);
            $query->addQueries->putPos($aq,$z->SatzTyp -100);
        }
/* macht keinen Sinn, weil ohnehin eine eigene Tabelle für die Klasse benötigt wird        
        if ($z->SatzTyp >= 150
            && $z->SatzTyp < 200){
                $dim = new Dimension($z->attribute);
                $query->dimensions[] = $dim;
        }
    */
    }
    $stmt->closeCursor();
    }
    if (isValid($query->currentLanguage)){
            $query->defaultTitle = qTranslate::translateQuery($query, $query->defaultTitle);
            $query->outputTitlePrefix = qTranslate::translateQuery($query, $query->outputTitlePrefix);
            $query->phys_table = qTranslate::translateTable($query, $query->phys_table);
            qTranslate::readQueryDescription($query);
    }else {
        $query->currentLanguage = 'de';
        error_log('Default de für '.$query->class_table);
    }
    
    /**
     * Bei neuer Version Kommentar aus queryComment einlesen
     */
//    error_log('Query-Version: '.$queryVersion.' '.($queryVersion > 0.6));
    if ($queryVersion > 0.6){
       $z = false; 
       $sql = new SqlAbfrage('WSR');
       $sql->sql = 'select SortNr, kommentar from queryComment';
       $sql->addSel('table_name = ', $query->class_table);
       $sql->addSel('qLanguage = ', $query->currentLanguage);
       $sql->sql .= ' order by SortNr';
       $stmt = $sql->executeE(true);
       if ($stmt !== false){
           $z = $stmt->fetchObject();
           if ($z === false){
               $sql = new SqlAbfrage('WSR');
               $sql->sql = 'select SortNr, kommentar from queryComment';
               $sql->addSel('table_name = ', $query->class_table);
               $sql->addSel('qLanguage = ', $query->qLanguage);
               $sql->sql .= ' order by SortNr';
               $stmt = $sql->executeE(true);
               if ($stmt !== false){
                   $z = $stmt->fetchObject();
               }
           }
        }
        if ($z !== false){
            $query->table_description = $z->kommentar;
            while ($z = $stmt->fetchObject()) $query->table_description .= $z->kommentar;
            while (substr($query->table_description, strlen($query->table_description)-1) == "\n")
                $query->table_description = substr($query->table_description, 0, strlen($query->table_description)-1);
        }

        $z = false;
        $sql = new SqlAbfrage('WSR');
        $sql->sql = 'select SortNr, kommentar from queryHints';
        $sql->addSel('table_name = ', $query->class_table);
        $sql->addSel('qLanguage = ', $query->currentLanguage);
        $sql->sql .= ' order by SortNr';
        $stmt = $sql->executeE(true);
        if ($stmt !== false){
            $z = $stmt->fetchObject();
            if ($z === false){
                $sql = new SqlAbfrage('WSR');
                $sql->sql = 'select SortNr, kommentar from queryHints';
                $sql->addSel('table_name = ', $query->class_table);
                $sql->addSel('qLanguage = ', $query->qLanguage);
                $sql->sql .= ' order by SortNr';
                $stmt = $sql->executeE(true);
                if ($stmt !== false){
                    $z = $stmt->fetchObject();
                }
            }
        }
        if ($z !== false){
            $query->table_hints = $z->kommentar;
            while ($z = $stmt->fetchObject()) $query->table_hints .= $z->kommentar;
            while (substr($query->table_hints, strlen($query->table_hints)-1) == "\n")
                $query->table_hints = substr($query->table_hints, 0, strlen($query->table_hints)-1);
        }
        
    }
// Die Dimensionen müssen vor den Metarecords eingelesen werden,
// weil dort die added Query manchmal initialisiert wird 
    $sql = new SqlAbfrage('WSR');
    $sql->sql = "select * from queryDimensions";
    $sql->addSel('table_name = ', $query->class_table);
    $sql->sql .= " order by SortNr";
    $stmt = $sql->execute();
    
    while($z = $stmt->fetchObject()){
        $dim = new Dimension($z);
        $query->dimensions[$z->SortNr] = $dim;
    }
    $stmt->closeCursor();
    
    $sql = new SqlAbfrage('WSR');
    $sql->sql = "select * from queryColumnMetadata";
    $sql->addSel('table_name = ', $query->class_table);
    $sql->sql .= " order by SpaltenTyp, SortNr";
    $stmt = $sql->execute();
    
    while($z = $stmt->fetchObject()){
        $column_name = $z->column_name;
        $metaRecord = new MetaRecord();
        $sTyp = $z->SpaltenTyp;
        $metaRecord->fillFrom($z,$query);
        
        if ($z->SpaltenTyp >= 100 && $mitJoins){         
            $sTyp -= 100; // ?????
            if ($sTyp >= $query->addQueries->size()){
                $dummy = new AddedQuery(null);                              
                $dummy->getQuery();
                $dummy->class_table = "Dummy";
                $query->addQueries->putPos($dummy,$sTyp);
//                echo " <b>Achtung dummy</b> ";
                echo "Eintrag DUMMY für Pos $sTyp  <br>\n";
            }
            $z->column_name = $column_name;
            $metaRecord->fillFrom($z,$query);
            if ($query->addQueries->getPos($sTyp) == null){
                echo "<br><b>FEHLER bei Query an Pos $sTyp mit $z->column_name</b>:<br><pre>";
                echo "varPos<br>";
                var_dump($query->addQueries->varPos);
                echo "\nvar<br>";
//                var_dump($query->addQueries->var);
                echo "</pre><br>";
            }else{
                $query->addQueries->getPos($sTyp)->calcVars[] = $metaRecord->getName();
                if ($query->addQueries->getPos($sTyp)->getQuery() == null){
                    echo "<br><b>FEHLER bei addQueries->getQuery() an Pos $sTyp </b>:<br><pre>";
                    var_dump($query->addQueries->getPos($sTyp));
                    echo "</pre><br>";
                }else{
                    // Metarecord Eintragen
                    $metaRecord->displayVar = null;
                    $query->addQueries->getPos($sTyp)->getQuery()->metaData[$metaRecord->getName()] = $metaRecord;
                }
            }
          }else{
            switch ($z->SpaltenTyp){
                case 1:
                    if ($column_name != 'WSR_WERTELISTE') $query->rowVars[] = $column_name;
                    break;
                case 2:
                    $query->valueVars[] = $column_name;
                    $metaRecord->displayVar = null;
                    break;
                case 3:
                    $query->filterVars[] = $column_name;
                    break;
            }  
            if ($z->SpaltenTyp <4) $query->metaData[$column_name] = $metaRecord;
        }
    }
    $stmt->closeCursor();

    $sql = new SqlAbfrage('WSR');
    $sql->sql = "select * from queryDefaultFilter";
    $sql->addSel('table_name = ', $query->class_table);
    $stmt = $sql->execute();
    if ($stmt === false){
        echo '<pre> '.$query->class_table." Default Filter:\n"; var_dump($sql->errorInfo()); var_dump($sql); echo '</pre>';
    }else{
        while($z = $stmt->fetchObject()){
            if (array_key_exists($z->column_name, $query->metaData)){
                $mr = $query->metaData[$z->column_name];
                if (false) $mr = new MetaRecord();
                if ($mr->filterType > MetaRecord::NONE){
                    $defaultFilter = new DefaultFilter($z->column_name);
                    if ($mr->filterType == MetaRecord::SONDERFILTERSEL){
                        $defaultFilter->fs_von = qTranslate::translate($z->qAddFilterVon);
                    }else
                        if (! isValid($mr->selectFilterTable)
                            && $mr->filterType == MetaRecord::SELECT){
                        $defaultFilter->fs_von = qTranslate::translate($z->qAddFilterVon);                                
                    }else
                        if (! isValid($mr->selectFilterTable)
                            && $mr->filterType == MetaRecord::VON_BIS_SELECT){
                        $defaultFilter->fs_von = qTranslate::translate($z->qAddFilterVon);
                        $defaultFilter->fs_bis = qTranslate::translate($z->qAddFilterBis);
                    }else{
                        $defaultFilter->fs_von = $z->qAddFilterVon;
                        $defaultFilter->fs_bis = $z->qAddFilterBis;
                    }
                    $query->defaultFilter[] = $defaultFilter;
                }
            }
         }
    }
    $stmt->closeCursor();
    $sourceSQL = $sourceSQLSave;
}
