<?php
/**
 * Projekt: WS-Reporter
 *          Installation: Report-Verzeichnis importieren
 *
 * Autor:    Wilfried Schollenberger
 *           WS Unternehmensberatung und Controlling-Systeme GmbH
 * Kontakt:  wisch@ws-unternehmensberatung.de
 * Lizenz:   GPL 3.0
 *
 * Importieren der Datenquellen und Report-Definitionen aus reports
 *
 * Stand:    14.9.2022
 *
 */
require_once 'includes/defender.inc';
require_once 'includes/funktionen.inc';
require_once './includes/wsrTranslate.inc';
require_once './includes/qTranslate.inc';
require_once './includes/importClassDef.inc';
require_once './includes/importReportDef.inc';

global $query;

function importTranslations($fileName){
    error_log('Start importTranslations '.$fileName);
    global $dbh;
    $start = 0;
    $fertig = false;
    $tFrom = null;
    $importe = array();
    $import = null;
    $sprachen = array('de','en','fr');
    
    $datei = fopen($fileName,'r');
    $sprachen = array('de','en','fr');
    while (($zeile = fgets($datei)) !== false && ! $fertig) {
        $zeile = trim($zeile);
        //    if ($start > 0) error_log($start.': '.$zeile);
        if ($zeile == "<WS-Report Translations Version 1.0>") $start = 1;
        //    else if (strpos($zeile,"<class>") === 0) ; // nichts machen
        else if ($start > 0 && strpos($zeile, '<translateFrom>') === 0){
            $tFrom = substr($zeile, strlen("<translateFrom>"));
            if ($tFrom == 'de') $start = 2;
            else {
                echo "<br>\nFehler beim Lesen der Übersetzung aus $fileName tFrom=".$tFrom;
                return;
            }
        }
        else if ($start >1 && strpos($zeile,"</WS-Report Translations>") === 0) {
            $fertig = true;
            $start = 0;            
        }
        else if ($start > 1
            && strpos($zeile,"<tReady>") === 0
            && $import != null){
                if (! array_key_exists($tFrom, $import)){
                    echo (WSRTranslate::translate('FEHLER in Import-Eintrag: Die Sprache').' '.$tFrom
                        .' '.WSRTranslate::translate('fehlt. Der Import wird abgebrochen.').'<br><pre>');
                    var_dump($import);
                    return;
                }
                $importe[$import[$tFrom]] = $import;
                $import = null;
        }elseif ($start > 1)
        foreach ($sprachen as $sprache)
            if (strpos($zeile,'<'.$sprache.'>') === 0){
                if ($import == null) {
                    $import = array();
                    $import['qLanguageType'] = (int) substr($zeile, strlen('<de>'));
                }
                $import[$sprache] = '';
                while (($zeile = fgets($datei)) !== false
                    && strpos($zeile,'</'.$sprache.'>') === false ){
                        $import[$sprache] .= $zeile;
                        //                error_log($zeile);
                }
                
                if (substr($import[$sprache],strlen($import[$sprache])-1) == "\n")
                    $import[$sprache] = substr($import[$sprache],0,strlen($import[$sprache])-1);
        }
    }
    $selectStmt = $dbh->prepare('select * from queryTranslations where de = :text');
    $insertStmt = $dbh->prepare('insert into queryTranslations set de = :de, en = :en, fr = :fr'
        .', qLanguageType = :qLanguageType');
//    echo '<pre>IMPORTE: '.print_r($importe,true).'</pre>';
    $count = 0;
    foreach ($importe as $key => $import){
        if (false === $selectStmt->execute(array ('text' => $import['de']))){
            echo "<pre>Fehler beim Lesen von queryTranslation:\n";
            echo $selectStmt->errorInfo()[2]."\nFür:\n";
            var_dump($selectStmt->errorInfo());
            echo $import[$tFrom];
            echo "\n tFrom = ".$tFrom."\n";
            var_dump($import);
            return;
        }
        $z = $selectStmt->fetch(PDO::FETCH_ASSOC);
        if ($z === false){
            $importe[$key]['status'] = 'neu';
            $p = array('qLanguageType' => $import['qLanguageType'] );
            
            foreach ($sprachen as $sprache){
                if (isset($import[$sprache])) $p[$sprache] = $import[$sprache];
                else $p[$sprache] = null;
            }
            if (false === $insertStmt->execute($p)){
                echo "\n<br>FEHLER beim Insert von ".$key."<br>\n";
                echo $insertStmt->errorInfo()[2];
                var_dump($insertStmt->errorInfo());
                echo "\n<br>Der Import der Übersetzung aus $fileName wird abgebrochen.";
                return;
            }
            $count ++;
        }
    }
    echo "\n<br>".$count.' '.WSRTranslate::translate('Übersetzungen importiert');
    error_log( $count.' '.WSRTranslate::translate('Übersetzungen importiert'));
}


if (session_status() == PHP_SESSION_NONE)  session_start();
anmeldungPruefen();
adminRechteVerlangen();
?>
<!DOCTYPE html>
<html>
<head>
<meta charset="UTF-8">
<title><?=WSRTranslate::translate('WS Reporter Installation').': '.WSRTranslate::translate('Report-Verzeichnis importieren') ?></title>
<meta name="GENERATOR" content="WS-PHP: wsrReportvrzImportieren.php">
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<link rel="stylesheet" href="./jscss/standard2.css">
</head>
<body>
<h1><?=WSRTranslate::translate('Report-Verzeichnis importieren') ?></h1>
<?php 
 $classDefs = array('WS_DQ_Datasource', 
     'WS_DQ_Dimensionen', 
     'WS_DQ_Label',  
     'WS_DQ_Used',
     'WSD_Report_Attributes', 
     'WSD_Report_Joins', 
     'WSD_Report_Rechte',
     'WSD_Report_Title',
     'WS_Report_Kommentare', 
     'WS_Table_Kommentare', 
     'WS_Table_Vrz', 
     'WS_Reports_Vrz',
     'WS_DQ_Admin', 
     'WS_Report_Admin'
 );
 foreach ($classDefs as $cld){
     echo "\n<br>".WSRTranslate::translate('Importiere').' <b>'.$cld.'</b>:';
     $datei = fopen('./reports/'.$cld.'.wsrc','r');
     importClassDef($datei);
     fclose($datei);
     echo "\n<br>".WSRTranslate::translate('Speichern').':';
     require './includes/saveClassDef.inc';
     importTranslations('./reports/'.$cld.'.wsrc');
     echo "<br>".WSRTranslate::translate('Fertig')."<br>\n";
 }
 $reportDefs = array('Report-Verzeichnis',
     'Datenquellen',
     'Reports und Datenquellen exportieren',
     'Datenquellen und Dimensionen exportieren',
     'Datenquellen Freigaben und Zuständigkeiten',
     'Datenquelle (Administration)',
     'Reports Freigaben und Zuständigkeiten',
     'Benutzung von Datenquellen',
     'Report-Infos'
 );
 $_REQUEST['bestaetigt'] = 'X';
 foreach ($reportDefs as $rd){
     echo "\n<br>".WSRTranslate::translate('Importiere Report'),' <b>'.$rd.'</b>:';
     $query = new Query('');
     $datei = fopen('./reports/'.$rd.'.wsr','r');
     importReportDef($datei);
     fclose($datei);
     echo "\n<br>".WSRTranslate::translate('Speichern').':';
     require './includes/saveReportDef.inc';
     importTranslations('./reports/'.$rd.'.wsr');
     echo "<br>".WSRTranslate::translate('Fertig')."<br>\n";
 }
?> 


</body>
</html>
